Module stream
llm_
tokenizer
1.3.2
Module stream
Module Items
Structs
In crate llm_
tokenizer
llm_tokenizer
Module
stream
Structs

Decode
Stream
DecodeStream will keep the state necessary to produce individual chunks of strings given an input stream of token_ids