pub struct DecodeStream { /* private fields */ }Expand description
DecodeStream will keep the state necessary to produce individual chunks of strings given an input stream of token_ids
Implementations
Sourceimpl DecodeStream
impl DecodeStream
pub fn new( tokenizer: Arc<dyn Tokenizer>, prompt_token_ids: &[TokenIdType], skip_special_tokens: bool, ) -> Self
Sourcepub fn step(&mut self, id: TokenIdType) -> Result<Option<String>>
pub fn step(&mut self, id: TokenIdType) -> Result<Option<String>>
Step appends a token_id to the internal state and tries to produce a text chunk.
Returning None means the given id is not enough to produce a chunk.