pub struct TiktokenTokenizer { /* private fields */ }Expand description
Tiktoken tokenizer wrapper — supports both built-in OpenAI encodings and hub-loaded models.
Implementations
Sourceimpl TiktokenTokenizer
impl TiktokenTokenizer
Sourcepub fn new(model: TiktokenModel) -> Result<Self>
pub fn new(model: TiktokenModel) -> Result<Self>
Create a new Tiktoken tokenizer for the specified built-in model
Sourcepub fn from_dir(dir: &Path) -> Result<Self>
pub fn from_dir(dir: &Path) -> Result<Self>
Create from a directory containing tiktoken.model + tokenizer_config.json
Sourcepub fn from_dir_with_chat_template(
dir: &Path,
chat_template_path: Option<&str>,
) -> Result<Self>
pub fn from_dir_with_chat_template( dir: &Path, chat_template_path: Option<&str>, ) -> Result<Self>
Create from a directory with an optional chat template file path.
Discovers the tiktoken model file automatically via find_tiktoken_file.
Sourcepub fn from_file(tiktoken_path: &Path) -> Result<Self>
pub fn from_file(tiktoken_path: &Path) -> Result<Self>
Create from an exact tiktoken file path (.tiktoken or tiktoken.model).
Looks for tokenizer_config.json in the same directory.
Sourcepub fn from_file_with_chat_template(
tiktoken_path: &Path,
chat_template_path: Option<&str>,
) -> Result<Self>
pub fn from_file_with_chat_template( tiktoken_path: &Path, chat_template_path: Option<&str>, ) -> Result<Self>
Create from an exact tiktoken file path with an optional chat template.
Sourcepub fn from_model_name(model_name: &str) -> Result<Self>
pub fn from_model_name(model_name: &str) -> Result<Self>
Create a tokenizer from a model string (e.g., “gpt-4”, “gpt-3.5-turbo”)