Enums
- Tokenizer
Type - Represents the type of tokenizer being used
Functions
- create_
tokenizer - Factory function to create tokenizer from a model name or path (blocking version)
- create_
tokenizer_ async - Factory function to create tokenizer from a model name or path (async version)
- create_
tokenizer_ async_ with_ chat_ template - Factory function to create tokenizer with optional chat template (async version)
- create_
tokenizer_ from_ file - Create a tokenizer from a file path to a tokenizer file. The file extension is used to determine the tokenizer type. Supported file types are:
- create_
tokenizer_ with_ chat_ template - Create a tokenizer from a file path with an optional chat template
- create_
tokenizer_ with_ chat_ template_ blocking - Factory function to create tokenizer with optional chat template (blocking version)
- discover_
chat_ template_ in_ dir - Helper function to discover chat template files in a directory
- get_
tokenizer_ info - Get information about a tokenizer file